==> apache-apisix-2.99.0-src.tgz: CODE_OF_CONDUCT.md <==
<!--
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
-->

*The following is copied for your convenience from <https://www.apache.org/foundation/policies/conduct.html>. If there's a discrepancy between the two, let us know or submit a PR to fix it.*

# Code of Conduct #

## Introduction ##

This code of conduct applies to all spaces managed by the Apache
Software Foundation, including IRC, all public and private mailing
lists, issue trackers, wikis, blogs, Twitter, and any other
communication channel used by our communities. A code of conduct which
is specific to in-person events (ie., conferences) is codified in the
published ASF anti-harassment policy.

We expect this code of conduct to be honored by everyone who
participates in the Apache community formally or informally, or claims
any affiliation with the Foundation, in any Foundation-related
activities and especially when representing the ASF, in any role.

This code __is not exhaustive or complete__. It serves to distill our
common understanding of a collaborative, shared environment and goals.
We expect it to be followed in spirit as much as in the letter, so that
it can enrich all of us and the technical communities in which we participate.

## Specific Guidelines ##

We strive to:

1. __Be open.__ We invite anyone to participate in our community. We preferably use public methods of communication for project-related messages, unless discussing something sensitive. This applies to messages for help or project-related support, too; not only is a public support request much more likely to result in an answer to a question, it also makes sure that any inadvertent mistakes made by people answering will be more easily detected and corrected.

2. __Be `empathetic`, welcoming, friendly, and patient.__ We work together to resolve conflict, assume good intentions, and do our best to act in an empathetic fashion. We may all experience some frustration from time to time, but we do not allow frustration to turn into a personal attack. A community where people feel uncomfortable or threatened is not a productive one. We should be respectful when dealing with other community members as well as with people outside our community.

3. __Be collaborative.__ Our work will be used by other people, and in turn we will depend on the work of others. When we make something for the benefit of the project, we are willing to explain to others how it works, so that they can build on the work to make it even better. Any decision we make will affect users and colleagues, and we take those consequences seriously when making decisions.

4. __Be inquisitive.__ Nobody knows everything! Asking questions early avoids many problems later, so questions are encouraged, though they may be directed to the appropriate forum. Those who are asked should be responsive and helpful, within the context of our shared goal of improving Apache project code.

5. __Be careful in the words that we choose.__ Whether we are participating as professionals or volunteers, we value professionalism in all interactions, and take responsibility for our own speech. Be kind to others. Do not insult or put down other participants. Harassment and other exclusionary behaviour are not acceptable. This includes, but is not limited to:

       * Violent threats or language directed against another person.
       * Sexist, racist, or otherwise discriminatory jokes and language.
       * Posting sexually explicit or violent material.
       * Posting (or threatening to post) other people's personally identifying information ("doxing").
       * Sharing private content, such as emails sent privately or non-publicly, or unlogged forums such as IRC channel history.
       * Personal insults, especially those using racist or sexist terms.
       * Unwelcome sexual attention.
       * Excessive or unnecessary profanity.
       * Repeated harassment of others. In general, if someone asks you to stop, then stop.
       * Advocating for, or encouraging, any of the above behaviour.

6. __Be concise.__ Keep in mind that what you write once will be read by hundreds of persons. Writing a short email means people can understand the conversation as efficiently as possible. Short emails should always strive to be empathetic, welcoming, friendly and patient. When a long explanation is necessary, consider adding a summary.</p>

      Try to bring new ideas to a conversation so that each mail adds something unique to the thread, keeping in mind that the rest of the thread still contains the other messages with arguments that have already been made.

      Try to stay on topic, especially in discussions that are already fairly large.

7. __Step down considerately.__ Members of every project come and go. When somebody leaves or disengages from the project they should tell people they are leaving and take the proper steps to ensure that others can pick up where they left off. In doing so, they should remain respectful of those who continue to participate in the project and should not misrepresent the project's goals or achievements. Likewise, community members should respect any individual's choice to leave the project.</p>

## Diversity Statement ##

Apache welcomes and encourages participation by everyone. We are committed to being a community that everyone feels good about joining. Although we may not be able to satisfy everyone, we will always work to treat everyone well.

No matter how you identify yourself or how others perceive you: we welcome you. Though no list can hope to be comprehensive, we explicitly honour diversity in: age, culture, ethnicity, genotype, gender identity or expression, language, national origin, neurotype, phenotype, political beliefs, profession, race, religion, sexual orientation, socioeconomic status, subculture and technical ability.

Though we welcome people fluent in all languages, Apache development is conducted in English.

Standards for behaviour in the Apache community are detailed in the Code of Conduct above. We expect participants in our community to meet these standards in all their interactions and to help others to do so as well.

## Reporting Guidelines ##

While this code of conduct should be adhered to by participants, we recognize that sometimes people may have a bad day, or be unaware of some of the guidelines in this code of conduct. When that happens, you may reply to them and point out this code of conduct. Such messages may be in public or in private, whatever is most appropriate. However, regardless of whether the message is public or not, it should still adhere to the relevant parts of this code of conduct; in particular, it should not be abusive or disrespectful.

If you believe someone is violating this code of conduct, you may reply to
them and point out this code of conduct. Such messages may be in public or in
private, whatever is most appropriate. Assume good faith; it is more likely
that participants are unaware of their bad behaviour than that they
intentionally try to degrade the quality of the discussion.  Should there be
difficulties in dealing with the situation, you may report your compliance
issues in confidence to either:

 * President of the Apache Software Foundation: Sam Ruby (rubys at intertwingly dot net)

or one of our volunteers:

  * [Mark Thomas](http://home.apache.org/~markt/coc.html)
  * [Joan Touzet](http://home.apache.org/~wohali/)
  * [Sharan Foga](http://home.apache.org/~sharan/coc.html)

If the violation is in documentation or code, for example inappropriate pronoun usage or word choice within official documentation, we ask that people report these privately to the project in question at private@<em>project</em>.apache.org, and, if they have sufficient ability within the project, to resolve or remove the concerning material, being mindful of the perspective of the person originally reporting the issue.

## End Notes ##

This Code defines __empathy__ as "a vicarious participation in the emotions, ideas, or opinions of others; the ability to imagine oneself in the condition or predicament of another." __Empathetic__ is the adjectival form of empathy.

This statement thanks the following, on which it draws for content and inspiration:

  * [CouchDB Project Code of conduct](http://couchdb.apache.org/conduct.html)
  * [Fedora Project Code of Conduct](http://fedoraproject.org/code-of-conduct)
  * [Django Code of Conduct](https://www.djangoproject.com/conduct/)
  * [Debian Code of Conduct](http://www.debian.org/vote/2014/vote_002)
  * [Twitter Open Source Code of Conduct](https://github.com/twitter/code-of-conduct/blob/master/code-of-conduct.md)
  * [Mozilla Code of Conduct/Draft](https://wiki.mozilla.org/Code_of_Conduct/Draft#Conflicts_of_Interest)
  * [Python Diversity Appendix](https://www.python.org/community/diversity/)
  * [Python Mentors Home Page](http://pythonmentors.com/)

==> apache-apisix-3.3.0-src.tgz: CODE_OF_CONDUCT.md <==
<!--
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
-->

*The following is copied for your convenience from <https://www.apache.org/foundation/policies/conduct.html>. If there's a discrepancy between the two, let us know or submit a PR to fix it.*

# Code of Conduct #

## Introduction ##

This code of conduct applies to all spaces managed by the Apache
Software Foundation, including IRC, all public and private mailing
lists, issue trackers, wikis, blogs, Twitter, and any other
communication channel used by our communities. A code of conduct which
is specific to in-person events (ie., conferences) is codified in the
published ASF anti-harassment policy.

We expect this code of conduct to be honored by everyone who
participates in the Apache community formally or informally, or claims
any affiliation with the Foundation, in any Foundation-related
activities and especially when representing the ASF, in any role.

This code __is not exhaustive or complete__. It serves to distill our
common understanding of a collaborative, shared environment and goals.
We expect it to be followed in spirit as much as in the letter, so that
it can enrich all of us and the technical communities in which we participate.

## Specific Guidelines ##

We strive to:

1. __Be open.__ We invite anyone to participate in our community. We preferably use public methods of communication for project-related messages, unless discussing something sensitive. This applies to messages for help or project-related support, too; not only is a public support request much more likely to result in an answer to a question, it also makes sure that any inadvertent mistakes made by people answering will be more easily detected and corrected.

2. __Be `empathetic`, welcoming, friendly, and patient.__ We work together to resolve conflict, assume good intentions, and do our best to act in an empathetic fashion. We may all experience some frustration from time to time, but we do not allow frustration to turn into a personal attack. A community where people feel uncomfortable or threatened is not a productive one. We should be respectful when dealing with other community members as well as with people outside our community.

3. __Be collaborative.__ Our work will be used by other people, and in turn we will depend on the work of others. When we make something for the benefit of the project, we are willing to explain to others how it works, so that they can build on the work to make it even better. Any decision we make will affect users and colleagues, and we take those consequences seriously when making decisions.

4. __Be inquisitive.__ Nobody knows everything! Asking questions early avoids many problems later, so questions are encouraged, though they may be directed to the appropriate forum. Those who are asked should be responsive and helpful, within the context of our shared goal of improving Apache project code.

5. __Be careful in the words that we choose.__ Whether we are participating as professionals or volunteers, we value professionalism in all interactions, and take responsibility for our own speech. Be kind to others. Do not insult or put down other participants. Harassment and other exclusionary behaviour are not acceptable. This includes, but is not limited to:

       * Violent threats or language directed against another person.
       * Sexist, racist, or otherwise discriminatory jokes and language.
       * Posting sexually explicit or violent material.
       * Posting (or threatening to post) other people's personally identifying information ("doxing").
       * Sharing private content, such as emails sent privately or non-publicly, or unlogged forums such as IRC channel history.
       * Personal insults, especially those using racist or sexist terms.
       * Unwelcome sexual attention.
       * Excessive or unnecessary profanity.
       * Repeated harassment of others. In general, if someone asks you to stop, then stop.
       * Advocating for, or encouraging, any of the above behaviour.

6. __Be concise.__ Keep in mind that what you write once will be read by hundreds of people. Writing a short email means people can understand the conversation as efficiently as possible. Short emails should always strive to be empathetic, welcoming, friendly and patient. When a long explanation is necessary, consider adding a summary.</p>

      Try to bring new ideas to a conversation so that each mail adds something unique to the thread, keeping in mind that the rest of the thread still contains the other messages with arguments that have already been made.

      Try to stay on topic, especially in discussions that are already fairly large.

7. __Step down considerately.__ Members of every project come and go. When somebody leaves or disengages from the project they should tell people they are leaving and take the proper steps to ensure that others can pick up where they left off. In doing so, they should remain respectful of those who continue to participate in the project and should not misrepresent the project's goals or achievements. Likewise, community members should respect any individual's choice to leave the project.</p>

## Diversity Statement ##

Apache welcomes and encourages participation by everyone. We are committed to being a community that everyone feels good about joining. Although we may not be able to satisfy everyone, we will always work to treat everyone well.

No matter how you identify yourself or how others perceive you: we welcome you. Though no list can hope to be comprehensive, we explicitly honour diversity in: age, culture, ethnicity, genotype, gender identity or expression, language, national origin, neurotype, phenotype, political beliefs, profession, race, religion, sexual orientation, socioeconomic status, subculture and technical ability.

Though we welcome people fluent in all languages, Apache development is conducted in English.

Standards for behaviour in the Apache community are detailed in the Code of Conduct above. We expect participants in our community to meet these standards in all their interactions and to help others to do so as well.

## Reporting Guidelines ##

While this code of conduct should be adhered to by participants, we recognize that sometimes people may have a bad day, or be unaware of some of the guidelines in this code of conduct. When that happens, you may reply to them and point out this code of conduct. Such messages may be in public or in private, whatever is most appropriate. However, regardless of whether the message is public or not, it should still adhere to the relevant parts of this code of conduct; in particular, it should not be abusive or disrespectful.

If you believe someone is violating this code of conduct, you may reply to
them and point out this code of conduct. Such messages may be in public or in
private, whatever is most appropriate. Assume good faith; it is more likely
that participants are unaware of their bad behaviour than that they
intentionally try to degrade the quality of the discussion.  Should there be
difficulties in dealing with the situation, you may report your compliance
issues in confidence to either:

 * President of the Apache Software Foundation: Sam Ruby (rubys at intertwingly dot net)

or one of our volunteers:

  * [Mark Thomas](http://home.apache.org/~markt/coc.html)
  * [Joan Touzet](http://home.apache.org/~wohali/)
  * [Sharan Foga](http://home.apache.org/~sharan/coc.html)

If the violation is in documentation or code, for example inappropriate pronoun usage or word choice within official documentation, we ask that people report these privately to the project in question at private@<em>project</em>.apache.org, and, if they have sufficient ability within the project, to resolve or remove the concerning material, being mindful of the perspective of the person originally reporting the issue.

## End Notes ##

This Code defines __empathy__ as "a vicarious participation in the emotions, ideas, or opinions of others; the ability to imagine oneself in the condition or predicament of another." __Empathetic__ is the adjectival form of empathy.

This statement thanks the following, on which it draws for content and inspiration:

  * [CouchDB Project Code of conduct](http://couchdb.apache.org/conduct.html)
  * [Fedora Project Code of Conduct](http://fedoraproject.org/code-of-conduct)
  * [Django Code of Conduct](https://www.djangoproject.com/conduct/)
  * [Debian Code of Conduct](http://www.debian.org/vote/2014/vote_002)
  * [Twitter Open Source Code of Conduct](https://github.com/twitter/code-of-conduct/blob/master/code-of-conduct.md)
  * [Mozilla Code of Conduct/Draft](https://wiki.mozilla.org/Code_of_Conduct/Draft#Conflicts_of_Interest)
  * [Python Diversity Appendix](https://www.python.org/community/diversity/)
  * [Python Mentors Home Page](http://pythonmentors.com/)
